pub struct LastSeenMessagesValidator {
tracked_messages: VecDeque<Option<TrackedEntry>>,
last_pending_signature: Option<Box<[u8]>>,
}Expand description
Validates that the client is properly acknowledging messages sent by the server
Fields
tracked_messages: VecDeque<Option<TrackedEntry>>last_pending_signature: Option<Box<[u8]>>Implementations
Sourceimpl LastSeenMessagesValidator
impl LastSeenMessagesValidator
Sourcepub fn add_pending(&mut self, signature: Option<Box<[u8]>>)
pub fn add_pending(&mut self, signature: Option<Box<[u8]>>)
Adds a pending message signature that the client should acknowledge Matches vanilla’s deduplication: only adds if different from last pending message
Sourcepub fn tracked_count(&self) -> usize
pub fn tracked_count(&self) -> usize
Gets the number of tracked messages
Sourcepub fn apply_offset(&mut self, offset: i32) -> Result<(), String>
pub fn apply_offset(&mut self, offset: i32) -> Result<(), String>
Applies an offset (removes old acknowledged messages from tracking)
Sourcepub fn apply_update(
&mut self,
acknowledged: [u8; 3],
offset: i32,
checksum: u8,
) -> Result<Vec<Box<[u8]>>, String>
pub fn apply_update( &mut self, acknowledged: [u8; 3], offset: i32, checksum: u8, ) -> Result<Vec<Box<[u8]>>, String>
Applies an acknowledgement update from the client
acknowledged: BitSet of 20 bits indicating which messages in the window are acknowledged
offset: How many old messages to remove from the window
checksum: Optional checksum for validation (0 = skip checksum)